"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import th2_grpc_common.common_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CheckpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    DESCRIPTION_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    description: typing.Text = ...

    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...

    def __init__(self,
        *,
        description : typing.Text = ...,
        parent_event_id : typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"parent_event_id",b"parent_event_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"description",b"description",u"parent_event_id",b"parent_event_id"]) -> None: ...
global___CheckpointRequest = CheckpointRequest

class CheckpointResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHECKPOINT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int

    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint: ...

    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...

    def __init__(self,
        *,
        checkpoint : typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        status : typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"checkpoint",b"checkpoint",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"checkpoint",b"checkpoint",u"status",b"status"]) -> None: ...
global___CheckpointResponse = CheckpointResponse

class ChainID(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ID_FIELD_NUMBER: builtins.int
    id: typing.Text = ...

    def __init__(self,
        *,
        id : typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"id",b"id"]) -> None: ...
global___ChainID = ChainID

class CheckRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONNECTIVITY_ID_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ROOT_FILTER_FIELD_NUMBER: builtins.int
    CHECKPOINT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    timeout: builtins.int = ...
    description: typing.Text = ...
    direction: th2_grpc_common.common_pb2.Direction.V = ...

    @property
    def connectivity_id(self) -> th2_grpc_common.common_pb2.ConnectionID: ...

    @property
    def filter(self) -> th2_grpc_common.common_pb2.MessageFilter: ...

    @property
    def root_filter(self) -> th2_grpc_common.common_pb2.RootMessageFilter: ...

    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint: ...

    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...

    @property
    def chain_id(self) -> global___ChainID: ...

    def __init__(self,
        *,
        connectivity_id : typing.Optional[th2_grpc_common.common_pb2.ConnectionID] = ...,
        filter : typing.Optional[th2_grpc_common.common_pb2.MessageFilter] = ...,
        root_filter : typing.Optional[th2_grpc_common.common_pb2.RootMessageFilter] = ...,
        checkpoint : typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        timeout : builtins.int = ...,
        parent_event_id : typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        description : typing.Text = ...,
        direction : th2_grpc_common.common_pb2.Direction.V = ...,
        chain_id : typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"checkpoint",b"checkpoint",u"connectivity_id",b"connectivity_id",u"filter",b"filter",u"kind",b"kind",u"parent_event_id",b"parent_event_id",u"root_filter",b"root_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"checkpoint",b"checkpoint",u"connectivity_id",b"connectivity_id",u"description",b"description",u"direction",b"direction",u"filter",b"filter",u"kind",b"kind",u"parent_event_id",b"parent_event_id",u"root_filter",b"root_filter",u"timeout",b"timeout"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal[u"kind",b"kind"]) -> typing_extensions.Literal["filter","root_filter"]: ...
global___CheckRuleRequest = CheckRuleRequest

class CheckRuleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int

    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...

    @property
    def chain_id(self) -> global___ChainID: ...

    def __init__(self,
        *,
        status : typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        chain_id : typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"status",b"status"]) -> None: ...
global___CheckRuleResponse = CheckRuleResponse

class CheckSequenceRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRE_FILTER_FIELD_NUMBER: builtins.int
    MESSAGE_FILTERS_FIELD_NUMBER: builtins.int
    ROOT_MESSAGE_FILTERS_FIELD_NUMBER: builtins.int
    CHECKPOINT_FIELD_NUMBER: builtins.int
    MESSAGETIMEOUT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    CONNECTIVITY_ID_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    CHECK_ORDER_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    messageTimeout: builtins.int = ...
    timeout: builtins.int = ...
    check_order: builtins.bool = ...
    description: typing.Text = ...
    direction: th2_grpc_common.common_pb2.Direction.V = ...

    @property
    def pre_filter(self) -> global___PreFilter: ...

    @property
    def message_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_common.common_pb2.MessageFilter]: ...

    @property
    def root_message_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[th2_grpc_common.common_pb2.RootMessageFilter]: ...

    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint: ...

    @property
    def connectivity_id(self) -> th2_grpc_common.common_pb2.ConnectionID: ...

    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...

    @property
    def chain_id(self) -> global___ChainID: ...

    def __init__(self,
        *,
        pre_filter : typing.Optional[global___PreFilter] = ...,
        message_filters : typing.Optional[typing.Iterable[th2_grpc_common.common_pb2.MessageFilter]] = ...,
        root_message_filters : typing.Optional[typing.Iterable[th2_grpc_common.common_pb2.RootMessageFilter]] = ...,
        checkpoint : typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        messageTimeout : builtins.int = ...,
        timeout : builtins.int = ...,
        connectivity_id : typing.Optional[th2_grpc_common.common_pb2.ConnectionID] = ...,
        parent_event_id : typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        check_order : builtins.bool = ...,
        description : typing.Text = ...,
        direction : th2_grpc_common.common_pb2.Direction.V = ...,
        chain_id : typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"checkpoint",b"checkpoint",u"connectivity_id",b"connectivity_id",u"parent_event_id",b"parent_event_id",u"pre_filter",b"pre_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"check_order",b"check_order",u"checkpoint",b"checkpoint",u"connectivity_id",b"connectivity_id",u"description",b"description",u"direction",b"direction",u"messageTimeout",b"messageTimeout",u"message_filters",b"message_filters",u"parent_event_id",b"parent_event_id",u"pre_filter",b"pre_filter",u"root_message_filters",b"root_message_filters",u"timeout",b"timeout"]) -> None: ...
global___CheckSequenceRuleRequest = CheckSequenceRuleRequest

class CheckSequenceRuleResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int

    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...

    @property
    def chain_id(self) -> global___ChainID: ...

    def __init__(self,
        *,
        status : typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        chain_id : typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"status",b"status"]) -> None: ...
global___CheckSequenceRuleResponse = CheckSequenceRuleResponse

class PreFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class FieldsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text = ...

        @property
        def value(self) -> th2_grpc_common.common_pb2.ValueFilter: ...

        def __init__(self,
            *,
            key : typing.Text = ...,
            value : typing.Optional[th2_grpc_common.common_pb2.ValueFilter] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal[u"value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"key",b"key",u"value",b"value"]) -> None: ...

    FIELDS_FIELD_NUMBER: builtins.int
    METADATA_FILTER_FIELD_NUMBER: builtins.int

    @property
    def fields(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, th2_grpc_common.common_pb2.ValueFilter]: ...

    @property
    def metadata_filter(self) -> th2_grpc_common.common_pb2.MetadataFilter: ...

    def __init__(self,
        *,
        fields : typing.Optional[typing.Mapping[typing.Text, th2_grpc_common.common_pb2.ValueFilter]] = ...,
        metadata_filter : typing.Optional[th2_grpc_common.common_pb2.MetadataFilter] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"metadata_filter",b"metadata_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"fields",b"fields",u"metadata_filter",b"metadata_filter"]) -> None: ...
global___PreFilter = PreFilter

class NoMessageCheckRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PRE_FILTER_FIELD_NUMBER: builtins.int
    MESSAGETIMEOUT_FIELD_NUMBER: builtins.int
    TIMEOUT_FIELD_NUMBER: builtins.int
    CHECKPOINT_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int
    CONNECTIVITY_ID_FIELD_NUMBER: builtins.int
    PARENT_EVENT_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    messageTimeout: builtins.int = ...
    timeout: builtins.int = ...
    description: typing.Text = ...
    direction: th2_grpc_common.common_pb2.Direction.V = ...

    @property
    def pre_filter(self) -> global___PreFilter: ...

    @property
    def checkpoint(self) -> th2_grpc_common.common_pb2.Checkpoint: ...

    @property
    def chain_id(self) -> global___ChainID: ...

    @property
    def connectivity_id(self) -> th2_grpc_common.common_pb2.ConnectionID: ...

    @property
    def parent_event_id(self) -> th2_grpc_common.common_pb2.EventID: ...

    def __init__(self,
        *,
        pre_filter : typing.Optional[global___PreFilter] = ...,
        messageTimeout : builtins.int = ...,
        timeout : builtins.int = ...,
        checkpoint : typing.Optional[th2_grpc_common.common_pb2.Checkpoint] = ...,
        chain_id : typing.Optional[global___ChainID] = ...,
        connectivity_id : typing.Optional[th2_grpc_common.common_pb2.ConnectionID] = ...,
        parent_event_id : typing.Optional[th2_grpc_common.common_pb2.EventID] = ...,
        description : typing.Text = ...,
        direction : th2_grpc_common.common_pb2.Direction.V = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"checkpoint",b"checkpoint",u"connectivity_id",b"connectivity_id",u"parent_event_id",b"parent_event_id",u"pre_filter",b"pre_filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"checkpoint",b"checkpoint",u"connectivity_id",b"connectivity_id",u"description",b"description",u"direction",b"direction",u"messageTimeout",b"messageTimeout",u"parent_event_id",b"parent_event_id",u"pre_filter",b"pre_filter",u"timeout",b"timeout"]) -> None: ...
global___NoMessageCheckRequest = NoMessageCheckRequest

class NoMessageCheckResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    STATUS_FIELD_NUMBER: builtins.int
    CHAIN_ID_FIELD_NUMBER: builtins.int

    @property
    def status(self) -> th2_grpc_common.common_pb2.RequestStatus: ...

    @property
    def chain_id(self) -> global___ChainID: ...

    def __init__(self,
        *,
        status : typing.Optional[th2_grpc_common.common_pb2.RequestStatus] = ...,
        chain_id : typing.Optional[global___ChainID] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"status",b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"chain_id",b"chain_id",u"status",b"status"]) -> None: ...
global___NoMessageCheckResponse = NoMessageCheckResponse
