# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: th2_grpc_check1/check1.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from th2_grpc_common import common_pb2 as th2__grpc__common_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='th2_grpc_check1/check1.proto',
  package='',
  syntax='proto3',
  serialized_options=b'\n\034com.exactpro.th2.check1.grpcP\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cth2_grpc_check1/check1.proto\x1a\x1cth2_grpc_common/common.proto\"K\n\x11\x43heckpointRequest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12!\n\x0fparent_event_id\x18\x02 \x01(\x0b\x32\x08.EventID\"U\n\x12\x43heckpointResponse\x12\x1f\n\ncheckpoint\x18\x01 \x01(\x0b\x32\x0b.Checkpoint\x12\x1e\n\x06status\x18\x02 \x01(\x0b\x32\x0e.RequestStatus\"\x15\n\x07\x43hainID\x12\n\n\x02id\x18\x01 \x01(\t\"\xbe\x02\n\x10\x43heckRuleRequest\x12&\n\x0f\x63onnectivity_id\x18\x01 \x01(\x0b\x32\r.ConnectionID\x12$\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x0e.MessageFilterB\x02\x18\x01H\x00\x12)\n\x0broot_filter\x18\n \x01(\x0b\x32\x12.RootMessageFilterH\x00\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12!\n\x0fparent_event_id\x18\x06 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x1d\n\tdirection\x18\x08 \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\t \x01(\x0b\x32\x08.ChainIDB\x06\n\x04kindJ\x04\x08\x05\x10\x06\"O\n\x11\x43heckRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\"\x99\x03\n\x18\x43heckSequenceRuleRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12+\n\x0fmessage_filters\x18\x02 \x03(\x0b\x32\x0e.MessageFilterB\x02\x18\x01\x12\x30\n\x14root_message_filters\x18\x0c \x03(\x0b\x32\x12.RootMessageFilter\x12\x1f\n\ncheckpoint\x18\x03 \x01(\x0b\x32\x0b.Checkpoint\x12\x16\n\x0emessageTimeout\x18\r \x01(\x03\x12\x0f\n\x07timeout\x18\x04 \x01(\x03\x12&\n\x0f\x63onnectivity_id\x18\x05 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x63heck_order\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x1d\n\tdirection\x18\n \x01(\x0e\x32\n.Direction\x12\x1a\n\x08\x63hain_id\x18\x0b \x01(\x0b\x32\x08.ChainIDJ\x04\x08\x06\x10\x07\"W\n\x19\x43heckSequenceRuleResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID\"\xa0\x01\n\tPreFilter\x12&\n\x06\x66ields\x18\x02 \x03(\x0b\x32\x16.PreFilter.FieldsEntry\x12(\n\x0fmetadata_filter\x18\x03 \x01(\x0b\x32\x0f.MetadataFilter\x1a;\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ValueFilter:\x02\x38\x01J\x04\x08\x01\x10\x02\"\x9c\x02\n\x15NoMessageCheckRequest\x12\x1e\n\npre_filter\x18\x01 \x01(\x0b\x32\n.PreFilter\x12\x16\n\x0emessageTimeout\x18\x02 \x01(\x03\x12\x0f\n\x07timeout\x18\x03 \x01(\x03\x12\x1f\n\ncheckpoint\x18\x04 \x01(\x0b\x32\x0b.Checkpoint\x12\x1a\n\x08\x63hain_id\x18\x05 \x01(\x0b\x32\x08.ChainID\x12&\n\x0f\x63onnectivity_id\x18\x06 \x01(\x0b\x32\r.ConnectionID\x12!\n\x0fparent_event_id\x18\x07 \x01(\x0b\x32\x08.EventID\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x1d\n\tdirection\x18\t \x01(\x0e\x32\n.Direction\"T\n\x16NoMessageCheckResponse\x12\x1e\n\x06status\x18\x01 \x01(\x0b\x32\x0e.RequestStatus\x12\x1a\n\x08\x63hain_id\x18\x02 \x01(\x0b\x32\x08.ChainID2\xa2\x02\n\x06\x43heck1\x12=\n\x10\x63reateCheckpoint\x12\x12.CheckpointRequest\x1a\x13.CheckpointResponse\"\x00\x12:\n\x0fsubmitCheckRule\x12\x11.CheckRuleRequest\x1a\x12.CheckRuleResponse\"\x00\x12R\n\x17submitCheckSequenceRule\x12\x19.CheckSequenceRuleRequest\x1a\x1a.CheckSequenceRuleResponse\"\x00\x12I\n\x14submitNoMessageCheck\x12\x16.NoMessageCheckRequest\x1a\x17.NoMessageCheckResponse\"\x00\x42 \n\x1c\x63om.exactpro.th2.check1.grpcP\x01\x62\x06proto3'
  ,
  dependencies=[th2__grpc__common_dot_common__pb2.DESCRIPTOR,])




_CHECKPOINTREQUEST = _descriptor.Descriptor(
  name='CheckpointRequest',
  full_name='CheckpointRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='CheckpointRequest.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='CheckpointRequest.parent_event_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=62,
  serialized_end=137,
)


_CHECKPOINTRESPONSE = _descriptor.Descriptor(
  name='CheckpointResponse',
  full_name='CheckpointResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='checkpoint', full_name='CheckpointResponse.checkpoint', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='CheckpointResponse.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=139,
  serialized_end=224,
)


_CHAINID = _descriptor.Descriptor(
  name='ChainID',
  full_name='ChainID',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ChainID.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=247,
)


_CHECKRULEREQUEST = _descriptor.Descriptor(
  name='CheckRuleRequest',
  full_name='CheckRuleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connectivity_id', full_name='CheckRuleRequest.connectivity_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='CheckRuleRequest.filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_filter', full_name='CheckRuleRequest.root_filter', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint', full_name='CheckRuleRequest.checkpoint', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='CheckRuleRequest.timeout', index=4,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='CheckRuleRequest.parent_event_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='CheckRuleRequest.description', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='CheckRuleRequest.direction', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='CheckRuleRequest.chain_id', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='CheckRuleRequest.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=250,
  serialized_end=568,
)


_CHECKRULERESPONSE = _descriptor.Descriptor(
  name='CheckRuleResponse',
  full_name='CheckRuleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='CheckRuleResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='CheckRuleResponse.chain_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=649,
)


_CHECKSEQUENCERULEREQUEST = _descriptor.Descriptor(
  name='CheckSequenceRuleRequest',
  full_name='CheckSequenceRuleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pre_filter', full_name='CheckSequenceRuleRequest.pre_filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_filters', full_name='CheckSequenceRuleRequest.message_filters', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root_message_filters', full_name='CheckSequenceRuleRequest.root_message_filters', index=2,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint', full_name='CheckSequenceRuleRequest.checkpoint', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messageTimeout', full_name='CheckSequenceRuleRequest.messageTimeout', index=4,
      number=13, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='CheckSequenceRuleRequest.timeout', index=5,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectivity_id', full_name='CheckSequenceRuleRequest.connectivity_id', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='CheckSequenceRuleRequest.parent_event_id', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_order', full_name='CheckSequenceRuleRequest.check_order', index=8,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='CheckSequenceRuleRequest.description', index=9,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='CheckSequenceRuleRequest.direction', index=10,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='CheckSequenceRuleRequest.chain_id', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=1061,
)


_CHECKSEQUENCERULERESPONSE = _descriptor.Descriptor(
  name='CheckSequenceRuleResponse',
  full_name='CheckSequenceRuleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='CheckSequenceRuleResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='CheckSequenceRuleResponse.chain_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1063,
  serialized_end=1150,
)


_PREFILTER_FIELDSENTRY = _descriptor.Descriptor(
  name='FieldsEntry',
  full_name='PreFilter.FieldsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='PreFilter.FieldsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='PreFilter.FieldsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1248,
  serialized_end=1307,
)

_PREFILTER = _descriptor.Descriptor(
  name='PreFilter',
  full_name='PreFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='PreFilter.fields', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_filter', full_name='PreFilter.metadata_filter', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PREFILTER_FIELDSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1153,
  serialized_end=1313,
)


_NOMESSAGECHECKREQUEST = _descriptor.Descriptor(
  name='NoMessageCheckRequest',
  full_name='NoMessageCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pre_filter', full_name='NoMessageCheckRequest.pre_filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='messageTimeout', full_name='NoMessageCheckRequest.messageTimeout', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='NoMessageCheckRequest.timeout', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='checkpoint', full_name='NoMessageCheckRequest.checkpoint', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='NoMessageCheckRequest.chain_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectivity_id', full_name='NoMessageCheckRequest.connectivity_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent_event_id', full_name='NoMessageCheckRequest.parent_event_id', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='NoMessageCheckRequest.description', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='direction', full_name='NoMessageCheckRequest.direction', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1600,
)


_NOMESSAGECHECKRESPONSE = _descriptor.Descriptor(
  name='NoMessageCheckResponse',
  full_name='NoMessageCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='NoMessageCheckResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='NoMessageCheckResponse.chain_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1602,
  serialized_end=1686,
)

_CHECKPOINTREQUEST.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_CHECKPOINTRESPONSE.fields_by_name['checkpoint'].message_type = th2__grpc__common_dot_common__pb2._CHECKPOINT
_CHECKPOINTRESPONSE.fields_by_name['status'].message_type = th2__grpc__common_dot_common__pb2._REQUESTSTATUS
_CHECKRULEREQUEST.fields_by_name['connectivity_id'].message_type = th2__grpc__common_dot_common__pb2._CONNECTIONID
_CHECKRULEREQUEST.fields_by_name['filter'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEFILTER
_CHECKRULEREQUEST.fields_by_name['root_filter'].message_type = th2__grpc__common_dot_common__pb2._ROOTMESSAGEFILTER
_CHECKRULEREQUEST.fields_by_name['checkpoint'].message_type = th2__grpc__common_dot_common__pb2._CHECKPOINT
_CHECKRULEREQUEST.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_CHECKRULEREQUEST.fields_by_name['direction'].enum_type = th2__grpc__common_dot_common__pb2._DIRECTION
_CHECKRULEREQUEST.fields_by_name['chain_id'].message_type = _CHAINID
_CHECKRULEREQUEST.oneofs_by_name['kind'].fields.append(
  _CHECKRULEREQUEST.fields_by_name['filter'])
_CHECKRULEREQUEST.fields_by_name['filter'].containing_oneof = _CHECKRULEREQUEST.oneofs_by_name['kind']
_CHECKRULEREQUEST.oneofs_by_name['kind'].fields.append(
  _CHECKRULEREQUEST.fields_by_name['root_filter'])
_CHECKRULEREQUEST.fields_by_name['root_filter'].containing_oneof = _CHECKRULEREQUEST.oneofs_by_name['kind']
_CHECKRULERESPONSE.fields_by_name['status'].message_type = th2__grpc__common_dot_common__pb2._REQUESTSTATUS
_CHECKRULERESPONSE.fields_by_name['chain_id'].message_type = _CHAINID
_CHECKSEQUENCERULEREQUEST.fields_by_name['pre_filter'].message_type = _PREFILTER
_CHECKSEQUENCERULEREQUEST.fields_by_name['message_filters'].message_type = th2__grpc__common_dot_common__pb2._MESSAGEFILTER
_CHECKSEQUENCERULEREQUEST.fields_by_name['root_message_filters'].message_type = th2__grpc__common_dot_common__pb2._ROOTMESSAGEFILTER
_CHECKSEQUENCERULEREQUEST.fields_by_name['checkpoint'].message_type = th2__grpc__common_dot_common__pb2._CHECKPOINT
_CHECKSEQUENCERULEREQUEST.fields_by_name['connectivity_id'].message_type = th2__grpc__common_dot_common__pb2._CONNECTIONID
_CHECKSEQUENCERULEREQUEST.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_CHECKSEQUENCERULEREQUEST.fields_by_name['direction'].enum_type = th2__grpc__common_dot_common__pb2._DIRECTION
_CHECKSEQUENCERULEREQUEST.fields_by_name['chain_id'].message_type = _CHAINID
_CHECKSEQUENCERULERESPONSE.fields_by_name['status'].message_type = th2__grpc__common_dot_common__pb2._REQUESTSTATUS
_CHECKSEQUENCERULERESPONSE.fields_by_name['chain_id'].message_type = _CHAINID
_PREFILTER_FIELDSENTRY.fields_by_name['value'].message_type = th2__grpc__common_dot_common__pb2._VALUEFILTER
_PREFILTER_FIELDSENTRY.containing_type = _PREFILTER
_PREFILTER.fields_by_name['fields'].message_type = _PREFILTER_FIELDSENTRY
_PREFILTER.fields_by_name['metadata_filter'].message_type = th2__grpc__common_dot_common__pb2._METADATAFILTER
_NOMESSAGECHECKREQUEST.fields_by_name['pre_filter'].message_type = _PREFILTER
_NOMESSAGECHECKREQUEST.fields_by_name['checkpoint'].message_type = th2__grpc__common_dot_common__pb2._CHECKPOINT
_NOMESSAGECHECKREQUEST.fields_by_name['chain_id'].message_type = _CHAINID
_NOMESSAGECHECKREQUEST.fields_by_name['connectivity_id'].message_type = th2__grpc__common_dot_common__pb2._CONNECTIONID
_NOMESSAGECHECKREQUEST.fields_by_name['parent_event_id'].message_type = th2__grpc__common_dot_common__pb2._EVENTID
_NOMESSAGECHECKREQUEST.fields_by_name['direction'].enum_type = th2__grpc__common_dot_common__pb2._DIRECTION
_NOMESSAGECHECKRESPONSE.fields_by_name['status'].message_type = th2__grpc__common_dot_common__pb2._REQUESTSTATUS
_NOMESSAGECHECKRESPONSE.fields_by_name['chain_id'].message_type = _CHAINID
DESCRIPTOR.message_types_by_name['CheckpointRequest'] = _CHECKPOINTREQUEST
DESCRIPTOR.message_types_by_name['CheckpointResponse'] = _CHECKPOINTRESPONSE
DESCRIPTOR.message_types_by_name['ChainID'] = _CHAINID
DESCRIPTOR.message_types_by_name['CheckRuleRequest'] = _CHECKRULEREQUEST
DESCRIPTOR.message_types_by_name['CheckRuleResponse'] = _CHECKRULERESPONSE
DESCRIPTOR.message_types_by_name['CheckSequenceRuleRequest'] = _CHECKSEQUENCERULEREQUEST
DESCRIPTOR.message_types_by_name['CheckSequenceRuleResponse'] = _CHECKSEQUENCERULERESPONSE
DESCRIPTOR.message_types_by_name['PreFilter'] = _PREFILTER
DESCRIPTOR.message_types_by_name['NoMessageCheckRequest'] = _NOMESSAGECHECKREQUEST
DESCRIPTOR.message_types_by_name['NoMessageCheckResponse'] = _NOMESSAGECHECKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CheckpointRequest = _reflection.GeneratedProtocolMessageType('CheckpointRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPOINTREQUEST,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:CheckpointRequest)
  })
_sym_db.RegisterMessage(CheckpointRequest)

CheckpointResponse = _reflection.GeneratedProtocolMessageType('CheckpointResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKPOINTRESPONSE,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:CheckpointResponse)
  })
_sym_db.RegisterMessage(CheckpointResponse)

ChainID = _reflection.GeneratedProtocolMessageType('ChainID', (_message.Message,), {
  'DESCRIPTOR' : _CHAINID,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:ChainID)
  })
_sym_db.RegisterMessage(ChainID)

CheckRuleRequest = _reflection.GeneratedProtocolMessageType('CheckRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKRULEREQUEST,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:CheckRuleRequest)
  })
_sym_db.RegisterMessage(CheckRuleRequest)

CheckRuleResponse = _reflection.GeneratedProtocolMessageType('CheckRuleResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKRULERESPONSE,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:CheckRuleResponse)
  })
_sym_db.RegisterMessage(CheckRuleResponse)

CheckSequenceRuleRequest = _reflection.GeneratedProtocolMessageType('CheckSequenceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHECKSEQUENCERULEREQUEST,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:CheckSequenceRuleRequest)
  })
_sym_db.RegisterMessage(CheckSequenceRuleRequest)

CheckSequenceRuleResponse = _reflection.GeneratedProtocolMessageType('CheckSequenceRuleResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHECKSEQUENCERULERESPONSE,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:CheckSequenceRuleResponse)
  })
_sym_db.RegisterMessage(CheckSequenceRuleResponse)

PreFilter = _reflection.GeneratedProtocolMessageType('PreFilter', (_message.Message,), {

  'FieldsEntry' : _reflection.GeneratedProtocolMessageType('FieldsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PREFILTER_FIELDSENTRY,
    '__module__' : 'th2_grpc_check1.check1_pb2'
    # @@protoc_insertion_point(class_scope:PreFilter.FieldsEntry)
    })
  ,
  'DESCRIPTOR' : _PREFILTER,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:PreFilter)
  })
_sym_db.RegisterMessage(PreFilter)
_sym_db.RegisterMessage(PreFilter.FieldsEntry)

NoMessageCheckRequest = _reflection.GeneratedProtocolMessageType('NoMessageCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOMESSAGECHECKREQUEST,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:NoMessageCheckRequest)
  })
_sym_db.RegisterMessage(NoMessageCheckRequest)

NoMessageCheckResponse = _reflection.GeneratedProtocolMessageType('NoMessageCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOMESSAGECHECKRESPONSE,
  '__module__' : 'th2_grpc_check1.check1_pb2'
  # @@protoc_insertion_point(class_scope:NoMessageCheckResponse)
  })
_sym_db.RegisterMessage(NoMessageCheckResponse)


DESCRIPTOR._options = None
_CHECKRULEREQUEST.fields_by_name['filter']._options = None
_CHECKSEQUENCERULEREQUEST.fields_by_name['message_filters']._options = None
_PREFILTER_FIELDSENTRY._options = None

_CHECK1 = _descriptor.ServiceDescriptor(
  name='Check1',
  full_name='Check1',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1689,
  serialized_end=1979,
  methods=[
  _descriptor.MethodDescriptor(
    name='createCheckpoint',
    full_name='Check1.createCheckpoint',
    index=0,
    containing_service=None,
    input_type=_CHECKPOINTREQUEST,
    output_type=_CHECKPOINTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='submitCheckRule',
    full_name='Check1.submitCheckRule',
    index=1,
    containing_service=None,
    input_type=_CHECKRULEREQUEST,
    output_type=_CHECKRULERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='submitCheckSequenceRule',
    full_name='Check1.submitCheckSequenceRule',
    index=2,
    containing_service=None,
    input_type=_CHECKSEQUENCERULEREQUEST,
    output_type=_CHECKSEQUENCERULERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='submitNoMessageCheck',
    full_name='Check1.submitNoMessageCheck',
    index=3,
    containing_service=None,
    input_type=_NOMESSAGECHECKREQUEST,
    output_type=_NOMESSAGECHECKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHECK1)

DESCRIPTOR.services_by_name['Check1'] = _CHECK1

# @@protoc_insertion_point(module_scope)
